print("aaa")


def my_one():
    print("pip first test")
